summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorwtc%netscape.com <devnull@localhost>1998-09-24 06:14:26 +0000
committerwtc%netscape.com <devnull@localhost>1998-09-24 06:14:26 +0000
commitf48d157133c6eb4cf9bda9ccc4ffcd5b521cc5a0 (patch)
treebbb24909ff3cb15b8c46b4e09cbaf082421d349b
parentebfa18ed079d724de88f96d463e2d61bdf0cd19b (diff)
downloadnspr-hg-f48d157133c6eb4cf9bda9ccc4ffcd5b521cc5a0.tar.gz
Got rid of references to "OSF1" in this file. Thanks to
raff@aromatic.com for the problem report and the patch.
-rw-r--r--pr/src/md/unix/linux.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/pr/src/md/unix/linux.c b/pr/src/md/unix/linux.c
index 637044cc..ac880597 100644
--- a/pr/src/md/unix/linux.c
+++ b/pr/src/md/unix/linux.c
@@ -82,11 +82,11 @@ _MD_WAKEUP_WAITER(PRThread *thread)
return PR_SUCCESS;
}
/* These functions should not be called for OSF1 */
void
_MD_YIELD(void)
{
- PR_NOT_REACHED("_MD_YIELD should not be called for OSF1.");
+ PR_NOT_REACHED("_MD_YIELD should not be called for Linux.");
}
PRStatus
@@ -98,7 +98,7 @@ _MD_CREATE_THREAD(
PRThreadState state,
PRUint32 stackSize)
{
- PR_NOT_REACHED("_MD_CREATE_THREAD should not be called for OSF1.");
+ PR_NOT_REACHED("_MD_CREATE_THREAD should not be called for Linux.");
return PR_FAILURE;
}
#endif /* ! _PR_PTHREADS */
@@ -82,11 +82,11 @@ _MD_WAKEUP_WAITER(PRThread *thread)
return PR_SUCCESS;
}
-/* These functions should not be called for OSF1 */
+/* These functions should not be called for Linux */
void
_MD_YIELD(void)